#' Run the core safetyGraphics App
#'
#' @param domainData named list of data.frames to be loaded in to the app. Sample AdAM data from the safetyData package used by default
#' @param meta data frame containing the metadata for use in the app. See the preloaded file (\code{?safetyGraphics::meta}) for more data specifications and details. Defaults to \code{safetyGraphics::meta}. 
#' @param charts list of charts in the format produced by safetyGraphics::makeChartConfig()
#' @param mapping list specifying the initial mapping values for each data mapping for each domain (e.g. list(aes= list(id_col='USUBJID', seq_col='AESEQ')). 
#' @param autoMapping boolean indicating whether the app should attempt to automatically detect data standards and generate mappings for the data provided. Values specified in the `mapping` parameter overwrite automatically generated mappings when both are found. Defaults to true.
#' @param filterDomain domain used for the data/filter tab. Demographics ("`dm`") is used by default. Using a domain that is not one record per participant is not recommended. 
#' @param chartSettingsPaths path(s) where customization functions are saved relative to your working directory. All charts can have initialization (e.g. myChart_Init.R) and static charts can have charting functions (e.g. myGraphic_Chart.R).   All R files in this folder are sourced and files with the correct naming convention are linked to the chart. See the Custom Charts vignette for more details. 
#'
#' @import shiny
#' @import safetyData
#' 
#' @export

safetyGraphicsApp <- function(
  domainData=list(
    labs=safetyData::adam_adlbc, 
    aes=safetyData::adam_adae, 
    dm=safetyData::adam_adsl
  ),
  meta = safetyGraphics::meta, 
  charts=NULL,
  mapping=NULL,
  autoMapping=TRUE,
  filterDomain="dm",
  chartSettingsPaths = NULL
){
  message("Initializing safetyGraphicsApp")
  config <- app_startup(domainData, meta, charts, mapping, autoMapping, filterDomain, chartSettingsPaths)

  app <- shinyApp(
    ui =  safetyGraphicsUI("sg",config$meta, config$domainData, config$mapping, config$standards),
    server = function(input,output,session){
      callModule(
        safetyGraphicsServer,
        "sg",
        config$meta, 
        config$mapping, 
        config$domainData, 
        config$charts, 
        config$filterDomain
      )
    }
  )
  runApp(app, launch.browser = TRUE)
}
